summaryrefslogtreecommitdiff
path: root/django/utils
diff options
context:
space:
mode:
authorVasiliy Faronov <vfaronov@gmail.com>2016-05-02 15:35:05 +0300
committerTim Graham <timograham@gmail.com>2016-05-03 11:16:27 -0400
commitcb33e553ee537da4915f9055f8cdf9bf32113aed (patch)
treec6702e0a96871b02ba573128706dcd03c1d4db2f /django/utils
parentd3a16b2bbec0eb8ac6c717962073ce4d126a46d3 (diff)
[1.9.x] Fixed #26567 -- Updated references to obsolete RFC2616.
Didn't touch comments where it wasn't obvious that the code adhered to the newer standard. Backport of ac77c55bc5fc54cd763a7ae426784650a8cc97c9 from master
Diffstat (limited to 'django/utils')
-rw-r--r--django/utils/cache.py2
-rw-r--r--django/utils/http.py6
2 files changed, 4 insertions, 4 deletions
diff --git a/django/utils/cache.py b/django/utils/cache.py
index c8ab96fe3d..24f9825f06 100644
--- a/django/utils/cache.py
+++ b/django/utils/cache.py
@@ -6,7 +6,7 @@ that header-patching themselves.
For information on the Vary header, see:
- http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.44
+ https://tools.ietf.org/html/rfc7231#section-7.1.4
Essentially, the "Vary" HTTP header defines which headers a cache should take
into account when building its cache key. Requests with the same path but
diff --git a/django/utils/http.py b/django/utils/http.py
index 62e854da8a..c053185a8a 100644
--- a/django/utils/http.py
+++ b/django/utils/http.py
@@ -114,7 +114,7 @@ def cookie_date(epoch_seconds=None):
def http_date(epoch_seconds=None):
"""
Formats the time to match the RFC1123 date format as specified by HTTP
- RFC2616 section 3.3.1.
+ RFC7231 section 7.1.1.1.
Accepts a floating point number expressed in seconds since the epoch, in
UTC - such as that outputted by time.time(). If set to None, defaults to
@@ -127,7 +127,7 @@ def http_date(epoch_seconds=None):
def parse_http_date(date):
"""
Parses a date format as specified by HTTP RFC2616 section 3.3.1.
The three formats allowed by the RFC are accepted, even if only the first
one is still in widespread use.
@@ -135,7 +135,7 @@ def parse_http_date(date):
Returns an integer expressed in seconds since the epoch, in UTC.
"""
# emails.Util.parsedate does the job for RFC1123 dates; unfortunately
# RFC2616 makes it mandatory to support RFC850 dates too. So we roll
# our own RFC-compliant parsing.
for regex in RFC1123_DATE, RFC850_DATE, ASCTIME_DATE:
m = regex.match(date)
@@ -127,7 +127,7 @@ def http_date(epoch_seconds=None):
def parse_http_date(date):
"""
- Parses a date format as specified by HTTP RFC2616 section 3.3.1.
+ Parses a date format as specified by HTTP RFC7231 section 7.1.1.1.
The three formats allowed by the RFC are accepted, even if only the first
one is still in widespread use.
@@ -135,7 +135,7 @@ def parse_http_date(date):
"""
# emails.Util.parsedate does the job for RFC1123 dates; unfortunately
- # RFC2616 makes it mandatory to support RFC850 dates too. So we roll
+ # RFC7231 makes it mandatory to support RFC850 dates too. So we roll
# our own RFC-compliant parsing.
for regex in RFC1123_DATE, RFC850_DATE, ASCTIME_DATE: